# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-07-11 21:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0039_contentplacement_page_number'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='type',
            field=models.CharField(choices=[('text', 'Text'), ('photo', 'Photo'), ('video', 'Video'), ('graphic', 'Graphic'), ('infobox', 'Infobox'), ('audio', 'Audio'), ('other', 'Other'), ('interactive', 'Interactive (discontinued)'), ('aggregation', 'Aggregation (discontinued)')], default='text', max_length=25),
        ),
    ]
